<?php
function extractDataFromXML($filePath) {
    $xml = simplexml_load_file($filePath, null, LIBXML_NOCDATA);
    $namespaces = $xml->getNamespaces(true);

    $xml->registerXPathNamespace('cbc', $namespaces['cbc']);
    $xml->registerXPathNamespace('cac', $namespaces['cac']);

    $data = [
        'Furnizor' => (string) $xml->xpath('//cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cbc:RegistrationName')[0],
        'Seria si nr.' => (string) $xml->xpath('//cbc:ID')[0],
        'Data emiterii' => (string) $xml->xpath('//cbc:IssueDate')[0],
        'Data scadenta' => (string) $xml->xpath('//cbc:DueDate')[0],
        'Valoare factura' => (string) $xml->xpath('//cac:LegalMonetaryTotal/cbc:PayableAmount')[0],
    ];

    return $data;
}

function insertFurnizor($conn, $furnizor) {
    $sql = "SELECT id FROM furnizori WHERE nume = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("s", $furnizor);
    $stmt->execute();
    $stmt->store_result();
    
    if ($stmt->num_rows > 0) {
        $stmt->bind_result($furnizor_id);
        $stmt->fetch();
        $stmt->close();
        return $furnizor_id;
    } else {
        $stmt->close();
        $sql = "INSERT INTO furnizori (nume) VALUES (?)";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("s", $furnizor);
        $stmt->execute();
        $furnizor_id = $stmt->insert_id;
        $stmt->close();
        return $furnizor_id;
    }
}

function facturaExista($conn, $furnizor_id, $nr_factura) {
    $sql = "SELECT id FROM facturi WHERE furnizor_id = ? AND nr_factura = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("is", $furnizor_id, $nr_factura);
    $stmt->execute();
    $stmt->store_result();
    
    $exista = $stmt->num_rows > 0;
    $stmt->close();
    
    return $exista;
}

function insertFactura($conn, $furnizor_id, $data) {
    if (!facturaExista($conn, $furnizor_id, $data['Seria si nr.'])) {
        $sql = "INSERT INTO facturi (furnizor_id, nr_factura, data_factura, data_scadenta, total_factura) VALUES (?, ?, ?, ?, ?)";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("isssd", $furnizor_id, $data['Seria si nr.'], $data['Data emiterii'], $data['Data scadenta'], $data['Valoare factura']);
        $stmt->execute();
        $stmt->close();
        return true; // Factura a fost adăugată
    }
    return false; // Factura deja există
}

if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_FILES['xmlFiles'])) {
    include 'config.php';

    $files = $_FILES['xmlFiles'];
    $num_files = count($files['name']);
    $facturiAdaugate = 0;
    $facturiExistente = 0;

    for ($i = 0; $i < $num_files; $i++) {
        $file_path = $files['tmp_name'][$i];
        $data = extractDataFromXML($file_path);

        $furnizor_id = insertFurnizor($conn, $data['Furnizor']);
        if (insertFactura($conn, $furnizor_id, $data)) {
            $facturiAdaugate++;
        } else {
            $facturiExistente++;
        }
    }

    $conn->close();

    // Redirecționare înapoi la add_factura.php cu mesajele relevante
    header("Location: add_factura.php?facturiAdaugate=$facturiAdaugate&facturiExistente=$facturiExistente");
    exit();
}

?>
